@@ -12,7 +12,7 @@ def check(web):
     return True
     
 
-def hdfans_upload(web,file1,record_path,qbinfo):
+def hdfans_upload(web,file1,record_path,qbinfo,basic):
 
     if (file1.pathinfo.type=='anime' or file1.pathinfo.type=='tv') and file1.pathinfo.collection==0:
         fileinfo=file1.chinesename+'在'+web.site.sitename+'第'+file1.episodename+'集'
