@@ -7,7 +7,7 @@ from selenium.webdriver.support.select import Select
 import re
 from selenium.webdriver.common.by import By
 
-def pter_upload(web,file1,record_path,qbinfo):
+def pter_upload(web,file1,record_path,qbinfo,basic):
 
     if (file1.pathinfo.type=='anime' or file1.pathinfo.type=='tv') and file1.pathinfo.collection==0:
         fileinfo=file1.chinesename+'在'+web.site.sitename+'第'+file1.episodename+'集'
@@ -192,7 +192,10 @@ def pter_upload(web,file1,record_path,qbinfo):
         logger.warning('选择匿名发布发生错误，错误信息: %s' %(r))
 
 
-    a=input('check')
+    #a=input('check')
+    if 'check' in basic and str(basic['check']).strip()=='1':
+        a=input('是否确实发布，如果确认请回车，不发布请手动结束程序或者关闭终端')
+        
     String_url = web.driver.current_url;
     try:
         web.driver.find_elements(By.ID,'qr')[0].click()
@@ -207,7 +210,7 @@ def pter_upload(web,file1,record_path,qbinfo):
     downloadurl=finddownloadurl(driver=web.driver,elementstr='/html/body/table[2]/tbody/tr[2]/td/table[1]/tbody/tr[9]/td[2]/a')
     if downloadurl=='已存在':
         return True,fileinfo+'种子发布失败,失败原因:种子'+downloadurl+',当前网址:'+web.driver.current_url
-    a=input('check')
+    #a=input('check')
     
     recordupload(os.path.join(record_path,web.site.sitename+'_torrent.csv'),file1,String_url,downloadurl)
     if not downloadurl =='':
